%include %{_rpmconfigdir}/macros.perl

Name: git
Version: 2.39.3
Release: 3
License: GPL-2.0-only
Summary: Distributed version control system
Url: https://git-scm.com

BuildRequires: libiconv-devel
BuildRequires: curl-devel
BuildRequires: expat-devel
BuildRequires: zlib-devel
BuildRequires: findutils
BuildRequires: pcre2-devel

Requires: less

Source0: https://www.kernel.org/pub/software/scm/git/git-%{version}.tar.xz

Patch0: config.mak.uname.patch
Patch1: t_t5003-archive-zip.sh.patch
Patch2: git-fileno-macro.patch
Patch3: git-journal-error-message.patch

%description
Git is a free and open source distributed version control system designed to
handle everything from small to very large projects with speed and efficiency.

Git is easy to learn and has a tiny footprint with lightning fast performance.
It outclasses SCM tools like Subversion, CVS, Perforce, and ClearCase with
features like cheap local branching, convenient staging areas, and multiple
workflows.

%package subtree
Summary: Git tool to merge and split repositories
Requires: %{name} = %{version}-%{release}

%description subtree
Git subtrees allow subprojects to be included within a subdirectory of the main
project, optionally including the subproject's entire history.


%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

#Fix shebang line
find . -type f -print0 | xargs -0 perl -p -i -e 's|/usr/bin/perl|%{_bindir}/perl|g'

%build

MAKE=`which make`
# generate a script to wrap the make call
# with all the parameters that we need
cat > _make <<EOF
#!/usr/bin/env bash

$MAKE \
  prefix=%{_prefix} \
  sysconfdir=%{_sysconfdir} \
  CC=gcc \
  DESTDIR=%{buildroot} \
  CFLAGS="-maix${OBJECT_MODE} -mminimal-toc -I%{_includedir} -I%{_includedir}/libiconv" \
  LDFLAGS="-maix${OBJECT_MODE} -mminimal-toc -Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
  PERL_PATH="%{_bindir}/perl" \
  SHELL_PATH="%{_bindir}/bash" \
  GIT_TEST_CMP='diff -u' \
  NO_TCLTK=YesPlease \
  NO_GETTEXT=YesPlease \
  NO_OPENSSL=YesPlease \
  USE_LIBPCRE2=YesPlease \
  perllibdir=%{perl_sitelib}\
  "\$@"
EOF

chmod +x _make

./_make

%check

# build and run tests
# NOTE: This must be run as a non-*ALLOBJ user or tests will fail
# ./t5570-git-daemon.sh and ./t5811-proto-disable-git.sh require git-daemon, skip
GIT_SKIP_TESTS='t5570 t5811' ./_make test


%install

./_make install

rm %{buildroot}/%{_libexecdir}/git-core/git-daemon
rm %{buildroot}/%{_libexecdir}/git-core/git-p4
rm -r %{buildroot}/%{_datadir}/gitweb

# Install git-subtree
cd contrib/subtree
make prefix=%{_prefix} DESTDIR=%{buildroot} install

%files
%defattr(-, qsys, *none)

%{_bindir}/*

%{perl_sitelib}/*

%dir %{_libexecdir}/git-core
%{_libexecdir}/git-core/git
%{_libexecdir}/git-core/git-add
%{_libexecdir}/git-core/git-add--interactive
%{_libexecdir}/git-core/git-am
%{_libexecdir}/git-core/git-annotate
%{_libexecdir}/git-core/git-apply
%{_libexecdir}/git-core/git-archimport
%{_libexecdir}/git-core/git-archive
%{_libexecdir}/git-core/git-bisect
%{_libexecdir}/git-core/git-bisect--helper
%{_libexecdir}/git-core/git-blame
%{_libexecdir}/git-core/git-branch
%{_libexecdir}/git-core/git-bugreport
%{_libexecdir}/git-core/git-bundle
%{_libexecdir}/git-core/git-cat-file
%{_libexecdir}/git-core/git-check-attr
%{_libexecdir}/git-core/git-check-ignore
%{_libexecdir}/git-core/git-check-mailmap
%{_libexecdir}/git-core/git-check-ref-format
%{_libexecdir}/git-core/git-checkout
%{_libexecdir}/git-core/git-checkout--worker
%{_libexecdir}/git-core/git-checkout-index
%{_libexecdir}/git-core/git-cherry
%{_libexecdir}/git-core/git-cherry-pick
%{_libexecdir}/git-core/git-clean
%{_libexecdir}/git-core/git-clone
%{_libexecdir}/git-core/git-column
%{_libexecdir}/git-core/git-commit
%{_libexecdir}/git-core/git-commit-graph
%{_libexecdir}/git-core/git-commit-tree
%{_libexecdir}/git-core/git-config
%{_libexecdir}/git-core/git-count-objects
%{_libexecdir}/git-core/git-credential
%{_libexecdir}/git-core/git-credential-cache
%{_libexecdir}/git-core/git-credential-cache--daemon
%{_libexecdir}/git-core/git-credential-store
%{_libexecdir}/git-core/git-cvsexportcommit
%{_libexecdir}/git-core/git-cvsimport
%{_libexecdir}/git-core/git-cvsserver
%{_libexecdir}/git-core/git-describe
%{_libexecdir}/git-core/git-diagnose
%{_libexecdir}/git-core/git-diff
%{_libexecdir}/git-core/git-diff-files
%{_libexecdir}/git-core/git-diff-index
%{_libexecdir}/git-core/git-diff-tree
%{_libexecdir}/git-core/git-difftool
%{_libexecdir}/git-core/git-difftool--helper
%{_libexecdir}/git-core/git-env--helper
%{_libexecdir}/git-core/git-fast-export
%{_libexecdir}/git-core/git-fast-import
%{_libexecdir}/git-core/git-fetch
%{_libexecdir}/git-core/git-fetch-pack
%{_libexecdir}/git-core/git-filter-branch
%{_libexecdir}/git-core/git-fmt-merge-msg
%{_libexecdir}/git-core/git-for-each-ref
%{_libexecdir}/git-core/git-for-each-repo
%{_libexecdir}/git-core/git-format-patch
%{_libexecdir}/git-core/git-fsck
%{_libexecdir}/git-core/git-fsck-objects
%{_libexecdir}/git-core/git-fsmonitor--daemon
%{_libexecdir}/git-core/git-gc
%{_libexecdir}/git-core/git-get-tar-commit-id
%{_libexecdir}/git-core/git-grep
%{_libexecdir}/git-core/git-hash-object
%{_libexecdir}/git-core/git-help
%{_libexecdir}/git-core/git-hook
%{_libexecdir}/git-core/git-http-backend
%{_libexecdir}/git-core/git-http-fetch
%{_libexecdir}/git-core/git-http-push
%{_libexecdir}/git-core/git-imap-send
%{_libexecdir}/git-core/git-index-pack
%{_libexecdir}/git-core/git-init
%{_libexecdir}/git-core/git-init-db
%{_libexecdir}/git-core/git-instaweb
%{_libexecdir}/git-core/git-interpret-trailers
%{_libexecdir}/git-core/git-log
%{_libexecdir}/git-core/git-ls-files
%{_libexecdir}/git-core/git-ls-remote
%{_libexecdir}/git-core/git-ls-tree
%{_libexecdir}/git-core/git-mailinfo
%{_libexecdir}/git-core/git-mailsplit
%{_libexecdir}/git-core/git-maintenance
%{_libexecdir}/git-core/git-merge
%{_libexecdir}/git-core/git-merge-base
%{_libexecdir}/git-core/git-merge-file
%{_libexecdir}/git-core/git-merge-index
%{_libexecdir}/git-core/git-merge-octopus
%{_libexecdir}/git-core/git-merge-one-file
%{_libexecdir}/git-core/git-merge-ours
%{_libexecdir}/git-core/git-merge-recursive
%{_libexecdir}/git-core/git-merge-resolve
%{_libexecdir}/git-core/git-merge-subtree
%{_libexecdir}/git-core/git-merge-tree
%{_libexecdir}/git-core/git-mergetool
%{_libexecdir}/git-core/git-mergetool--lib
%{_libexecdir}/git-core/git-mktag
%{_libexecdir}/git-core/git-mktree
%{_libexecdir}/git-core/git-multi-pack-index
%{_libexecdir}/git-core/git-mv
%{_libexecdir}/git-core/git-name-rev
%{_libexecdir}/git-core/git-notes
%{_libexecdir}/git-core/git-pack-objects
%{_libexecdir}/git-core/git-pack-redundant
%{_libexecdir}/git-core/git-pack-refs
%{_libexecdir}/git-core/git-patch-id
%{_libexecdir}/git-core/git-prune
%{_libexecdir}/git-core/git-prune-packed
%{_libexecdir}/git-core/git-pull
%{_libexecdir}/git-core/git-push
%{_libexecdir}/git-core/git-quiltimport
%{_libexecdir}/git-core/git-range-diff
%{_libexecdir}/git-core/git-read-tree
%{_libexecdir}/git-core/git-rebase
%{_libexecdir}/git-core/git-receive-pack
%{_libexecdir}/git-core/git-reflog
%{_libexecdir}/git-core/git-remote
%{_libexecdir}/git-core/git-remote-ext
%{_libexecdir}/git-core/git-remote-fd
%{_libexecdir}/git-core/git-remote-ftp
%{_libexecdir}/git-core/git-remote-ftps
%{_libexecdir}/git-core/git-remote-http
%{_libexecdir}/git-core/git-remote-https
%{_libexecdir}/git-core/git-repack
%{_libexecdir}/git-core/git-replace
%{_libexecdir}/git-core/git-request-pull
%{_libexecdir}/git-core/git-rerere
%{_libexecdir}/git-core/git-reset
%{_libexecdir}/git-core/git-restore
%{_libexecdir}/git-core/git-rev-list
%{_libexecdir}/git-core/git-rev-parse
%{_libexecdir}/git-core/git-revert
%{_libexecdir}/git-core/git-rm
%{_libexecdir}/git-core/git-send-email
%{_libexecdir}/git-core/git-send-pack
%{_libexecdir}/git-core/git-sh-i18n
%{_libexecdir}/git-core/git-sh-i18n--envsubst
%{_libexecdir}/git-core/git-sh-setup
%{_libexecdir}/git-core/git-shell
%{_libexecdir}/git-core/git-shortlog
%{_libexecdir}/git-core/git-show
%{_libexecdir}/git-core/git-show-branch
%{_libexecdir}/git-core/git-show-index
%{_libexecdir}/git-core/git-show-ref
%{_libexecdir}/git-core/git-sparse-checkout
%{_libexecdir}/git-core/git-stage
%{_libexecdir}/git-core/git-stash
%{_libexecdir}/git-core/git-status
%{_libexecdir}/git-core/git-stripspace
%{_libexecdir}/git-core/git-submodule
%{_libexecdir}/git-core/git-submodule--helper
%{_libexecdir}/git-core/git-svn
%{_libexecdir}/git-core/git-switch
%{_libexecdir}/git-core/git-symbolic-ref
%{_libexecdir}/git-core/git-tag
%{_libexecdir}/git-core/git-unpack-file
%{_libexecdir}/git-core/git-unpack-objects
%{_libexecdir}/git-core/git-update-index
%{_libexecdir}/git-core/git-update-ref
%{_libexecdir}/git-core/git-update-server-info
%{_libexecdir}/git-core/git-upload-archive
%{_libexecdir}/git-core/git-upload-pack
%{_libexecdir}/git-core/git-var
%{_libexecdir}/git-core/git-verify-commit
%{_libexecdir}/git-core/git-verify-pack
%{_libexecdir}/git-core/git-verify-tag
%{_libexecdir}/git-core/git-version
%{_libexecdir}/git-core/git-web--browse
%{_libexecdir}/git-core/git-whatchanged
%{_libexecdir}/git-core/git-worktree
%{_libexecdir}/git-core/git-write-tree
%{_libexecdir}/git-core/scalar

%dir %{_libexecdir}/git-core/mergetools
%{_libexecdir}/git-core/mergetools/araxis
%{_libexecdir}/git-core/mergetools/bc
%{_libexecdir}/git-core/mergetools/codecompare
%{_libexecdir}/git-core/mergetools/deltawalker
%{_libexecdir}/git-core/mergetools/diffmerge
%{_libexecdir}/git-core/mergetools/diffuse
%{_libexecdir}/git-core/mergetools/ecmerge
%{_libexecdir}/git-core/mergetools/emerge
%{_libexecdir}/git-core/mergetools/examdiff
%{_libexecdir}/git-core/mergetools/guiffy
%{_libexecdir}/git-core/mergetools/gvimdiff
%{_libexecdir}/git-core/mergetools/kdiff3
%{_libexecdir}/git-core/mergetools/kompare
%{_libexecdir}/git-core/mergetools/meld
%{_libexecdir}/git-core/mergetools/nvimdiff
%{_libexecdir}/git-core/mergetools/opendiff
%{_libexecdir}/git-core/mergetools/p4merge
%{_libexecdir}/git-core/mergetools/smerge
%{_libexecdir}/git-core/mergetools/tkdiff
%{_libexecdir}/git-core/mergetools/tortoisemerge
%{_libexecdir}/git-core/mergetools/vimdiff
%{_libexecdir}/git-core/mergetools/winmerge
%{_libexecdir}/git-core/mergetools/xxdiff

%{_datadir}/git-core/*

%files subtree
%defattr(-, qsys, *none)

%{_libexecdir}/git-core/git-subtree

%post
# Move gitconfig from old incorrect location /QOpenSys/pkgs/etc/ to new
# correct location /QOpenSys/etc/ if it exists and won't overwrite existing
# gitconfig
if [ -e %{_prefix}/etc/gitconfig -a ! -e %{_sysconfdir}/gitconfig ]
then
  mv %{_prefix}/etc/gitconfig %{_sysconfdir}/gitconfig
fi


%changelog
* Thu Nov 02 2023 Kevin Adler <kadler@us.ibm.com>
- Remove OpenSSL, only used by git-imap-send

* Wed Jun 28 2023 Kevin Adler <kadler@us.ibm.com>
- Add patch to print an error message hint to disable journaling when mmap
  fails with ENODEV

* Wed Apr 26 2023 Kevin Adler <kadler@us.ibm.com>
- Update to 2.39.3 for CVEs
- Fix CVE-2023-25652
- Fix CVE-2023-25815
- Fix CVE-2023-29007

* Thu Feb 09 2023 Kevin Adler <kadler@us.ibm.com>
- BuildRequire openssl-1.1-devel instead of openssl-devel

* Wed Jan 18 2023 Kevin Adler <kadler@us.ibm.com>
- Update to 2.39.1
- Fix CVE-2022-41903
- Fix CVE-2022-23521
- Fix CVE-2022-39260
- Fix CVE-2022-39253
- Fix CVE-2022-29187
- Package git-subtree

* Wed Feb 24 2021 Abdirahim Musse <abdirahim.musse@ibm.com>
- Make less the default git pager

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 2.26.2
- Build with PCRE2

* Mon Apr 27 2020 Naveen Ram <naveen.ram@ibm.com> - 2.26.2
- Update git to version 2.26.2
- Fix CVE-2017-14867
- Fix CVE-2020-5260

* Mon Apr 13 2020 Mark Irish <mirish@ibm.com> - 2.10.4
- Pass sysconfdir variable to make to set system config location correctly
- Post install script moves gitconfig to new location if able

* Mon Dec 16 2019 Mark Irish <mirish@ibm.com> - 2.10.4
- Use SPDX license identifier

* Wed Aug 07 2019 Mark Irish <mirish@ibm.com> - 2.10.4
- Update openssl-dev version to >= 1.1.1

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add build requirements

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Uncomment tests since check sections are disabled by build.py

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Bump to 2.10.4
- Build against expat now that we have it
- Use perl macros
- Remove gitweb and git-p4 along with gitd

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license
